/**
 * Creates a const map from the given values
 * @param values - An array of values to be used as keys and values in the map.
 * @returns A populated version of the map with the values and keys derived from the values.
 */
export declare function createConstMap<T>(values: Array<T[keyof T]>): T;
//# sourceMappingURL=utils.d.ts.map